@@ -6,12 +6,10 @@
 #' @export
 #' @examples
 #' rgb_country_codes(country_name="United")
-rgb_country_codes <- function(country_name, fuzzy=FALSE, ...)
-{
-  if(fuzzy){
+rgb_country_codes <- function(country_name, fuzzy = FALSE, ...) {
+  if (fuzzy) {
     isocodes[agrep(country_name, isocodes$name, ...),]
-  } else
-  {
+  } else {
     isocodes[grep(country_name, isocodes$name, ...),]
   }
 }
